spacepy.pycdf.CDFCopy — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- pycdf - Python interface to CDF files »

# spacepy.pycdf.CDFCopy

class `spacepy.pycdf.` `CDFCopy`(cdf)

  A dictionary-like copy of all data and attributes in a `CDF`

  Data are `VarCopy` objects, keyed by variable name. CDF attributes are in `attrs`. (I.e., data are accessed much like from a `CDF`).

  Do not instantiate this class directly; use `copy()` on an existing `CDF`.

  Examples

      >>> from spacepy import pycdf
      >>> with pycdf.CDF('test.cdf') as cdffile:
      ...     data = cdffile.copy()

  `attrs`

    Python dictionary containing attributes copied from the CDF.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- pycdf - Python interface to CDF files »